# :rocket: PopularAlgorithm :facepunch:
---
[算法优缺点][6]

商品打包购算法
https://mp.weixin.qq.com/s/diIzbc0tpCW4xhbIQu8mCw

[PRML算法实现][1]
[各种算法优缺点][3]

---
- lightning: 大规模线性回归、分类和排名库
- [skope-rules][4]
- [forest-confidence-interval][5]
---
## 经验参数
![经验参数][2]




---
[1]: https://github.com/ctgk/PRML
[2]: https://github.com/Jie-Yuan/GithubPicture/raw/master/ExperienceParameters.jpg
[3]: http://blog.csdn.net/u012422446/article/details/53034260
[4]: https://github.com/scikit-learn-contrib/skope-rules
[5]: https://github.com/scikit-learn-contrib/forest-confidence-interval

[6]: https://mp.weixin.qq.com/s?__biz=MzA4OTg5NzY3NA==&mid=2649345665&idx=1&sn=000c6e1ceada252162b803404d9a397c&chksm=880e8124bf790832dfc5b10e142425969799639743295078ee1d9524ab21e7ad1b314136d923&mpshare=1&scene=1&srcid=0528p1yaSx6dNlRh0U58XebG#rd





















